package com.nokia.common.command;

import com.xxl.job.core.context.XxlJobHelper;
import lombok.extern.slf4j.Slf4j;
import org.springframework.util.CollectionUtils;

import java.io.BufferedReader;
import java.io.IOException;
import java.io.InputStreamReader;
import java.util.ArrayList;
import java.util.List;

/**
 * 执行命令工具
 */
@Slf4j
public class CommandUtil {
    /**
     * 执行
     *
     * @param command 命令
     * @return {@link List}<{@link String}>
     * @throws IOException          ioexception
     * @throws InterruptedException 中断异常
     */
    public static List<String> exec(String command) throws IOException, InterruptedException {
        List<String> error = new ArrayList<>();
        List<String> input = new ArrayList<>();
        Process process = null;
        try {
            process = Runtime.getRuntime().exec(command);
            try (BufferedReader inputReader = new BufferedReader(new InputStreamReader(process.getInputStream()));
                 BufferedReader errorReader = new BufferedReader(new InputStreamReader(process.getErrorStream()))) {
                String line;
                // 读取错误流
                while ((line = errorReader.readLine()) != null) {
                    error.add(line);
                }
                // 读取标准流
                while ((line = inputReader.readLine()) != null) {
                    input.add(line);
                }
            }

            if (!CollectionUtils.isEmpty(input)) {
                log.info("inputStream: " + input);
                XxlJobHelper.log("inputStream: " + input);
            }
            int code = process.waitFor();
            // 非正常退出或错误流不为空
            if (code != 0 || !CollectionUtils.isEmpty(error)) {
                throw new RuntimeException(error.toString());
            }
            return input;
        } finally {
            if (process != null) {
                log.info("销毁进程");
                process.destroy();
            }
        }
    }
}
