package com.nokia.common.psql;

import com.nokia.common.command.CommandUtil;
import com.xxl.job.core.context.XxlJobHelper;
import lombok.extern.slf4j.Slf4j;

import java.io.IOException;
import java.util.List;
import java.util.regex.Matcher;
import java.util.regex.Pattern;

/**
 * psql命令工具
 */
@Slf4j
public class PsqlUtil {
    /**
     * 匹配psql copy成功结果
     */
    private static final Pattern PATTERN = Pattern.compile("^(COPY) (\\d+)$");

    /**
     * 导入csv
     *
     * @param script         脚本
     * @param dbHost         数据库主机
     * @param dbPort         数据库端口
     * @param dbUsername     数据库用户名
     * @param dbPassword     数据库密码
     * @param dbName         数据库名字
     * @param dbTable        数据库表
     * @param csv            csv
     * @param minInsertCount 最小值插入数
     * @throws IOException          ioexception
     * @throws InterruptedException 中断异常
     */
    public static void copyCsv(String script, String dbHost, Integer dbPort, String dbUsername, String dbPassword,
                               String dbName, String dbTable, String csv, Long minInsertCount)
            throws IOException, InterruptedException {
        String command = "sh"
                + " " + script
                + " " + dbHost
                + " " + dbPort
                + " " + dbUsername
                + " " + dbPassword
                + " " + dbName
                + " " + dbTable
                + " " + csv;
        List<String> list = CommandUtil.exec(command);
        Long count = null;
        for (String s : list) {
            Matcher matcher = PATTERN.matcher(s);
            while (matcher.find()) {
                count = Long.parseLong(matcher.group(2));
            }
        }
        if (count == null) {
            throw new RuntimeException("导入数据失败: " + list);
        }
        log.info("插入 {} 条数据", count);
        XxlJobHelper.log("插入 {} 条数据", count);
        if (count < minInsertCount) {
            throw new RuntimeException(csv + " 数据异常，少于 " + minInsertCount);
        }
    }
}
